Merge "binary test runner uses lazy android_device registration"
diff --git a/tools/build/tasks/vts_package.mk b/tools/build/tasks/vts_package.mk
index cf1185f..c37086c 100644
--- a/tools/build/tasks/vts_package.mk
+++ b/tools/build/tasks/vts_package.mk
@@ -158,7 +158,7 @@
   $(call find-files-in-subdirs,test/vts-testcase,"*.py" -and -type f,.) \
   $(call find-files-in-subdirs,test/vts-testcase,"*.config" -and -type f,.) \
   $(call find-files-in-subdirs,test/vts-testcase,"*.push" -and -type f,.) \
-  $(call find-files-in-subdirs,test/vts-testcase,"android-base.cfg" -and -type f,.)
+  $(call find-files-in-subdirs,test/vts-testcase,"android-base*.cfg" -and -type f,.)
 
 host_testcase_copy_pairs := \
   $(foreach f,$(host_testcase_files),\
diff --git a/utils/python/common/list_utils.py b/utils/python/common/list_utils.py
index 10694d5..1bb5659 100644
--- a/utils/python/common/list_utils.py
+++ b/utils/python/common/list_utils.py
@@ -67,13 +67,25 @@
 
 
 def DeduplicateKeepOrder(input):
-    '''Remove duplicate items from a sequence while keeping the item order
+    '''Remove duplicate items from a sequence while keeping the item order.
 
     Args:
         input: a sequence that might have duplicated items.
 
     Returns:
-        A deduplicated list where item order is kept
+        A deduplicated list where item order is kept.
+    '''
+    return MergeUniqueKeepOrder(input)
+
+
+def MergeUniqueKeepOrder(*lists):
+    '''Merge two list, remove duplicate items, and order.
+
+    Args:
+        lists: any number of lists
+
+    Returns:
+        A merged list where items are unique and original order is kept.
     '''
     seen = set()
-    return [x for x in input if not (x in seen or seen.add(x))]
+    return [x for x in itertools.chain(*lists) if not (x in seen or seen.add(x))]